Inner

Trait Inner 

pub trait Inner:
    Clone
    + Eq
    + Hash
    + PartialEq { }
A valid inner type for a Functor.

Clone is required because most non-trivial Functor implementations will need to clone their inner type. Eq and Hash are required to allow for Functor implementations involving maps and sets. It was determined that Hash was a less burdensome requirement than Ord.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Clone + Eq + Hash + PartialEq> Inner for T